# `BioClients.allen`

##  Allen Brain Atlas

Allen Brain Atlas REST API client

  * <https://help.brain-map.org/display/api/>

```
python3 -m BioClients.allen.brain.Client -h
```

Additional Allen Institute resources may be added in future.
